@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -20,9 +20,17 @@
 
 #include <medC_win_dll.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* Gestion des messages d'erreur */
 extern MEDC_EXPORT
-void exit_if(char * fichier,int ligne, int condition,char * message, char * arg); 
+void exit_if(const char * const fichier,int ligne, int condition,const char * const message, const char * const arg) ;
+
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* MED_EXIT_IF_H */
 
