@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -18,9 +18,19 @@
 #ifndef MED_VERSIONED_H
 #define MED_VERSIONED_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#include "med_versioned_proto_en.h"
+
 #include "med_versioned_proto.h"
 #include "med_versioned_hdfi.h"
 #include "med_versioned_cfi.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 
 #endif
