@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -21,11 +21,11 @@
 #include "medC_win_dll.h"
 #include <stdarg.h>
 
-/* Interfaces versionnes de l'API MED */
+/* Interfaces versionnées de l'API MED */
 
-/* Toutes les routines versionnes doivent avoir
-   un premier paramtre de type int foo  mme s'il
-   n'est pas utilis (cf : MEDOuvrirXYZ(int ,...)*/
+/* Toutes les routines versionnées doivent avoir
+   un premier paramètre de type int foo  même s'il
+   n'est pas utilisé (cf : MEDOuvrirXYZ(int ,...)*/
 
 /* Il faut ajouter une ligne dans le fichier misc/MEDversionedApi.cxx */
 
