@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -16,6 +16,7 @@
  */
 
 
+
 #include <med.h>
 #include <med_config.h>
 #include <med_outils.h>
@@ -30,7 +31,7 @@
  * - Resultat : l'ID du fils en cas de succes, -1 sinon
  */ 
 med_idt
-_MEDdatagroupOuvrir(med_idt pid, char *nom)
+_MEDdatagroupOuvrir(med_idt pid, const char * const nom)
 {
   med_idt id;
 
