@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -15,6 +15,7 @@
  *  along with MED.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+
 #include <med.h>
 #include <med_config.h>
 #include <med_outils.h>
@@ -31,7 +32,7 @@
 med_err
 _MEDdatasetFermer(med_idt id)
 {
-  med_err ret;
+  med_err ret=-1;
 
   if ((ret = H5Dclose(id)) < 0)
     return -1;
