@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -15,6 +15,7 @@
  *  along with MED.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+
 #include <med.h>
 #include <med_config.h>
 #include <med_outils.h>
@@ -31,9 +32,9 @@
 med_idt
 _MEDdatasetOuvrir(med_idt pid,char *nom)
 {
-  med_idt id;
+  med_idt id=0;
 
-  if ((id = H5Dopen(pid,nom)) < 0)
+  if ( (id = H5Dopen(pid,nom)) < 0)
     return -1;
 
   return id;
