@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -15,6 +15,7 @@
  *  along with MED.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+
 #include <med.h>
 #include <med_config.h>
 #include <med_outils.h>
@@ -34,9 +35,10 @@
 extern
 med_err _MEDfichierMonter(med_idt pid, const char *nom, med_idt fid)
 {
-  med_err ret = 0;
+  med_err _ret = 0;
 
-  ret = H5Fmount(pid,nom,fid,H5P_DEFAULT);
+  if (H5Fmount(pid,nom,fid,H5P_DEFAULT) < 0)
+    _ret = -1;
 
-  return ret;
+  return _ret;
 }
