@@ -1,6 +1,6 @@
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -34,7 +34,7 @@ extern "C" valueType getModeAcces(keyType key) {
   
   if (it != MedModeAcces.end() ) return (*it).second;
 
-  return MED_UNDEF_MODE_ACCES;
+  return MED_ACC_UNDEF;
 }
 
 extern "C" med_err setModeAcces(keyType key,valueType v) {
