@@ -3,7 +3,7 @@
 file=test27
 test "x${CPYMED}" = "xyes" && ${CP} ${SRCDIR}/test.med.ref ${BUILDDIR}/${file}.med && chmod 644 ${BUILDDIR}/${file}.med
 output=/dev/null && test "x${OUTPUT}" = "xyes" && output=${file}.out
-${CHECKER} ${EXECDIR}/${file} > ${output} 2>&1 && ${H5DUMP} -a /ENS_MAA/grille_cartesienne/DIM -a /ENS_MAA/grille_cartesienne/DES -a /ENS_MAA/grille_cartesienne/TYP -a /ENS_MAA/grille_cartesienne/GTY -g /ENS_MAA/grille_cartesienne/NOE -a /ENS_MAA/grille_standard/DIM -a /ENS_MAA/grille_standard/DES -a /ENS_MAA/grille_standard/TYP -a /ENS_MAA/grille_standard/GTY -g /ENS_MAA/grille_standard/NOE  -a /ENS_MAA/maillage\ vide/DIM -a /ENS_MAA/maillage\ vide/DES -a /ENS_MAA/maillage\ vide/TYP -g /INFOS_GENERALES ${BUILDDIR}/${file}.med > ${BUILDDIR}/${file}.dump  && ( \
+${CHECKER} ${EXECDIR}/${file} > ${output} 2>&1 && ${H5DUMP} ${BUILDDIR}/${file}.med > ${BUILDDIR}/${file}.dump  && ( \
 sed -e 's/DATATYPE  H5T_STD_I32BE//g' -e 's/DATATYPE  H5T_STD_I32LE//g'	 \
     -e 's/DATATYPE  H5T_STD_I64BE//g' -e 's/DATATYPE  H5T_STD_I64LE//g'  \
     -e 's/DATATYPE  H5T_IEEE_F64BE//g' -e 's/DATATYPE  H5T_IEEE_F64LE//g'  \
