@@ -1,6 +1,6 @@
 !*  This file is part of MED.
 !*
-!*  COPYRIGHT (C) 1999 - 2009  EDF R&D, CEA/DEN
+!*  COPYRIGHT (C) 1999 - 2011  EDF R&D, CEA/DEN
 !*  MED is free software: you can redistribute it and/or modify
 !*  it under the terms of the GNU Lesser General Public License as published by
 !*  the Free Software Foundation, either version 3 of the License, or
@@ -31,7 +31,7 @@ program test11
 
   integer       cret,ret,lret,retmem, fid
   integer       USER_INTERLACE,USER_MODE
-  character*32  :: maa,nomcha,pflname,nomlien,locname
+  character*64  :: maa,nomcha,pflname,nomlien,locname
   character*200 desc
   character*255 argc
   character*16, allocatable, dimension(:) :: comp,unit
@@ -44,9 +44,15 @@ program test11
   character*255 lien
   integer       i,j
   integer       getFieldsOn
+  integer nstep, stype, atype,sdim
+  character*16 nomcoo(3)   
+  character*16 unicoo(3)
+  integer lmesh, ncst
+  character*64  :: giname, isname
+  integer nsmc, sgtype
 
   parameter (USER_INTERLACE = MED_FULL_INTERLACE)
-  parameter (USER_MODE = MED_COMPACT )
+  parameter (USER_MODE = MED_COMPACT_PFLMODE)
 
   cret=0;ret=0;lret=0;retmem=0
   print *,"Indiquez le fichier med a decrire : "
@@ -54,11 +60,13 @@ program test11
   argc="test10.med"
 
   !  ** ouverture du fichier **
-  call efouvr(fid,argc,MED_LECTURE, ret)
+  call mfiope(fid,argc,MED_ACC_RDONLY, ret)
   if (ret .ne. 0) call efexit(-1)
 
   !  ** info sur le premier maillage **
-  call efmaai(fid,1,maa,mdim,type,desc,ret)
+  if (ret.eq.0) then
+     call mmhmii(fid,1,maa,sdim,mdim,type,desc,dtunit,stype,nstep,atype,nomcoo,unicoo,ret)
+  endif
   if (ret.ne.0) then
      print *, "Erreur a la lecture des informations sur le maillage : ", &
           & maa,mdim,type,desc
@@ -68,7 +76,7 @@ program test11
   write (*,'(/A,A,A,I1)') "Maillage de nom |",TRIM(maa),"| et de dimension ",mdim
 
   !  ** combien de champs dans le fichier **
-  call efncha(fid,0,ncha,ret)
+  call mfdnfd(fid,ncha,ret)
   if (ret.ne.0) then
      print *, "Impossible de lire le nombre de champs : ",ncha
      call efexit(-1)
@@ -83,7 +91,8 @@ program test11
      write(*,'(A,I5)') "- Champ numero : ",i
 
      ! ** combien de composantes **
-     call efncha(fid,i,ncomp,ret)
+     call mfdnfc(fid,i,ncomp,ret)
+     !   print *,ncomp,ret
      if (ret.ne.0) then
         print *, "Erreur a la lecture du nombre de composantes : ",ncomp
         cret = -1
@@ -92,49 +101,53 @@ program test11
      ! ** allocation memoire de comp et unit **
      allocate(comp(ncomp),unit(ncomp),STAT=retmem)
      if (retmem .ne. 0) then
-        print *, "Erreur a l'allocation mmoire de comp et unit : "
+        print *, "Erreur a l'allocation mémoire de comp et unit : "
         call efexit(-1)
      endif
 
      ! ** Info sur les champs
-     call efchai(fid,i,nomcha,typcha,comp,unit,ncomp,ret)
+     call mfdfdi(fid,i,nomcha,maa,lmesh,typcha,comp,unit,dtunit,ncst,ret)
      if (ret .ne. 0) then
-        print *, "Erreur a la demande d'information sur les champs : ",nomcha,typcha,comp,unit,ncomp
+        print *, "Erreur a la demande d'information sur les champs : ",nomcha,typcha,comp,unit,ncomp,ncst
         cret = -1
         continue
      endif
 
      write(*,'(/5X,A,A)') 'Nom du champ  : ', TRIM(nomcha)
+     write(*,'(/5X,A,A)') 'Nom du maillage : ',TRIM(maa)
      write(*,'(5X,A,I5)') 'Type du champ : ', typcha
+     write(*,'(5X,A,I1)') 'Nombre de composantes = ',ncomp
      do j=1,ncomp
         write(*,'(5X,A,I1,A,A,A,A)') 'Composante ',j,'  : ',TRIM(comp(j)),' ',TRIM(unit(j))
      enddo
-
-     deallocate(comp,unit)
+     write(*,'(5X,A,I1)') 'Nombre de pas de temps = ',ncst
      print *,""
 
-     lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_NOEUD, USER_INTERLACE )
+     deallocate(comp,unit)
+ 
+     lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_NODE, USER_INTERLACE, ncst)
+     ! print *,lret
 
      if (lret .eq. 0) then 
-        lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_MAILLE, USER_INTERLACE )
+        lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_CELL, USER_INTERLACE, ncst)
      else 
         print *, "Erreur a la lecture des champs aux noeuds "; cret = -1; continue 
      endif
 
      if (lret .eq. 0) then
-        lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_FACE,USER_INTERLACE)
+        lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_DESCENDING_FACE,USER_INTERLACE, ncst)
      else 
         print *,"Erreur a la lecture des champs aux mailles "; cret = -1; continue
      endif
 
      if (lret .eq. 0) then
-        lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_ARETE,USER_INTERLACE)
+        lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_DESCENDING_EDGE,USER_INTERLACE, ncst)
      else 
         print *,"Erreur a la lecture des champs aux faces "; cret = -1; continue
      endif
 
      if (lret .eq. 0) then
-        lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_NOEUD_MAILLE,USER_INTERLACE)
+        lret = getFieldsOn(fid, nomcha, typcha, ncomp, MED_NODE_ELEMENT,USER_INTERLACE, ncst)
      else 
         print *,"Erreur a la lecture des champs aux aretes "; cret = -1; continue
      endif
@@ -146,35 +159,36 @@ program test11
   enddo
 
 
-  call efnpro(fid,nval,ret)
-  write (*,'(5X,A,I2)') 'Nombre de profils stocks : ', nval
+  call mpfnpf(fid,nval,ret)
+  write (*,'(5X,A,I2)') 'Nombre de profils stockés : ', nval
 
   if (nval .gt. 0 ) then
      do i=1,nval
-        call efproi(fid,i,pflname,nval,ret)
+           call mpfpfi(fid,i,pflname,nval,ret)
         write (*,'(5X,A,I2,A,A,A,I2)') 'Profil n ',i,' : ',pflname, ' et de taille',nval
      enddo
   endif
 
+
   !  ** Interrogation des liens **
-  call efnlie(fid,nln,ret)
+  call mlnnln(fid,nln,ret)
   if (ret.ne.0) then
      print *,"Erreur a la lecture du nombre de liens : " & 
           & ,nln
      cret = -1; 
   else
      print *,""
-     print *,"Nombre de liens stockes : ",nln;print *,"";print *,""
+     write (*,'(5X,A,I5)') "Nombre de liens stockes : ",nln;print *,"";print *,""
      do i=1,nln
-        call efliei(fid, i, nomlien, nval, ret)
+        call mlnlni(fid, i, nomlien, nval, ret)
         if (ret.ne.0) then
-           print *,"Erreur a la demande d'information sur le lien n : ",i
+           print *,"Erreur a la demande d'information sur le lien n° : ",i
            cret = -1;continue;
         endif
-        write (*,'(5X,A,I4,A,A,A,I4)') "- Lien n",i," de nom |",TRIM(nomlien),"| et de taille ",nval
+        write (*,'(5X,A,I4,A,A,A,I4)') "- Lien n°",i," de nom |",TRIM(nomlien),"| et de taille ",nval
         !! allocate
         lien = ""
-        call efliel(fid,lien,nval,nomlien,ret)
+        call mlnlir(fid,nomlien,lien,ret)
         if (ret.ne.0) then
            print *,"Erreur a la lecture du lien : ", lien,nval,nomlien
            ret = -1; 
@@ -185,8 +199,9 @@ program test11
      end do
   endif
 
+
   !  ** Interrogation des localisations des points de GAUSS **
-  call efngau(fid,nloc,ret)
+  call mlcnlc(fid,nloc,ret)
   if (ret.ne.0) then
      print *,"Erreur a la lecture du nombre de points de Gauss : " & 
           & ,nloc
@@ -194,32 +209,32 @@ program test11
   else  
      print *,"Nombre de localisations stockees : ",nloc;print *,"";print *,""
      do i=1,nloc
-        call efgaui(fid, i, locname, type_geo, ngauss, ret)
+        call mlclci(fid, i, locname, type_geo, sdim, ngauss, giname, isname, nsmc, sgtype, ret)
         if (ret.ne.0) then
-           print *,"Erreur a la demande d'information sur la localisation n : ",i
+           print *,"Erreur a la demande d'information sur la localisation n° : ",i
            cret = -1;continue;
         endif
-        write (*,'(5X,A,I4,A,A,A,I4)') "- Loc n",i," de nom |",TRIM(locname) &
-             &,"| et nbr. de pts Gauss ",ngauss
-        t1 = MOD(type_geo,100)*(type_geo/100)
-        t2 = ngauss*(type_geo/100)
+        write (*,'(5X,A,I4,A,A,A,I4,A,I4)') "- Loc n°",i," de nom |",TRIM(locname) &
+             &,"| et nbr. de pts Gauss ",ngauss,"| et dans un espace de dimension ",sdim
+        t1 = MOD(type_geo,100)*sdim
+        t2 = ngauss*sdim
         t3 = ngauss
         allocate(refcoo(t1),STAT=retmem)
         if (retmem .ne. 0) then
-           print *, "Erreur a l'allocation mmoire de refcoo : "
+           print *, "Erreur a l'allocation mémoire de refcoo : "
            call efexit(-1)
         endif;
         allocate(gscoo(t2),STAT=retmem)
         if (retmem .ne. 0) then
-           print *, "Erreur a l'allocation mmoire de gscoo : "
+           print *, "Erreur a l'allocation mémoire de gscoo : "
            call efexit(-1)
         endif;
         allocate(wg(t3),STAT=retmem)
         if (retmem .ne. 0) then
-           print *, "Erreur a l'allocation mmoire de wg : "
+           print *, "Erreur a l'allocation mémoire de wg : "
            call efexit(-1)
         endif;
-        call efgaul(fid, refcoo, gscoo, wg, USER_INTERLACE, locname, ret )
+        call mlclor(fid, locname,USER_INTERLACE,refcoo,gscoo,wg, ret )
         if (ret.ne.0) then
            print *,"Erreur a la lecture  des valeurs de la localisation : " & 
                 & ,locname
@@ -247,99 +262,106 @@ program test11
      enddo
   endif
 
-  call efferm (fid,ret)
+  call mficlo(fid,ret)
+  !print *,ret
 
   call efexit(cret)
 
 end program test11
 
 
-integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage)
+integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage, ncst)
   implicit none
   include 'med.hf'
 
-  integer      ::fid,typcha,ncomp,entite,stockage
+  integer      ::fid,typcha,ncomp,entite,stockage, ncst
   character(LEN=*)  nomcha
 
   integer      :: j,k,l,m,n,nb_geo,cret,ret,retmem,nvl,nref
-  integer      :: nbpdtnor,pflsize,ngauss,ngroup,nval
+  integer      :: nbpdtnor,pflsize,ngauss,ngroup,nent,nprofile
   integer,     allocatable, dimension(:) :: pflval
   integer,     allocatable, dimension(:) :: vale
   integer      :: numdt,numo,lnsize,nbrefmaa
   real*8,      allocatable, dimension(:) :: valr
   real*8       dt
   logical      local
-  character*32 :: pflname,locname,maa_ass
+  character*64 :: pflname,locname,maa_ass
   character*16 :: dt_unit
   character*255:: lien
   integer       USER_MODE
 
   integer,pointer,dimension(:) :: type_geo
   integer,target  :: typ_noeud(1) = (/ MED_NONE /)
-  integer,target  :: typmai(MED_NBR_GEOMETRIE_MAILLE+2) =  (/ MED_POINT1,MED_SEG2,   &
+
+  integer :: MY_NOF_CELL_TYPE = 17 
+  integer :: MY_NOF_DESCENDING_FACE_TYPE =  5
+  integer :: MY_NOF_DESCENDING_EDGE_TYPE =  2
+
+  integer,target  :: typmai(17) =  (/ MED_POINT1,MED_SEG2,   &
        &  MED_SEG3,MED_TRIA3,     &
        &  MED_QUAD4,MED_TRIA6,    &
        &  MED_QUAD8,MED_TETRA4,   &
        &  MED_PYRA5,MED_PENTA6,   &
        &  MED_HEXA8,MED_TETRA10,  &
        &  MED_PYRA13,MED_PENTA15,  &
-       &  MED_HEXA20,MED_POLYGONE,&
-       &  MED_POLYEDRE/)
+       &  MED_HEXA20,MED_POLYGON,&
+       &  MED_POLYHEDRON/)
 
-  integer,target :: typfac(MED_NBR_GEOMETRIE_FACE+1) = (/MED_TRIA3,MED_TRIA6,       &
-       &  MED_QUAD4,MED_QUAD8,MED_POLYGONE/)
-  integer,target ::typare(MED_NBR_GEOMETRIE_ARETE) = (/MED_SEG2,MED_SEG3/)
+  integer,target :: typfac(5) = (/MED_TRIA3,MED_TRIA6,       &
+       &  MED_QUAD4,MED_QUAD8,MED_POLYGON/)
+  integer,target ::typare(2) = (/MED_SEG2,MED_SEG3/)
 
-  character(LEN=12),pointer,dimension(:) :: AFF
-  character(LEN=12),target,dimension(MED_NBR_GEOMETRIE_MAILLE+2) :: FMED_GEOMETRIE_MAILLE_AFF = (/&
-       &  "MED_POINT1  ",&
-       &  "MED_SEG2    ",&
-       &  "MED_SEG3    ",&
-       &  "MED_TRIA3   ",&
-       &  "MED_QUAD4   ",&
-       &  "MED_TRIA6   ",&
-       &  "MED_QUAD8   ",&
-       &  "MED_TETRA4  ",&
-       &  "MED_PYRA5   ",&
-       &  "MED_PENTA6  ",&
-       &  "MED_HEXA8   ",&
-       &  "MED_TETRA10 ",&
-       &  "MED_PYRA13  ",&
-       &  "MED_PENTA15 ",&
-       &  "MED_HEXA20  ",&
-       &  "MED_POLYGONE",&
-       &  "MED_POLYEDRE"  /)
+  character(LEN=15),pointer,dimension(:) :: AFF
+  character(LEN=15),target,dimension(17) :: FMED_GEOMETRIE_MAILLE_AFF = (/&
+       &  "MED_POINT1     ",&
+       &  "MED_SEG2       ",&
+       &  "MED_SEG3       ",&
+       &  "MED_TRIA3      ",&
+       &  "MED_QUAD4      ",&
+       &  "MED_TRIA6      ",&
+       &  "MED_QUAD8      ",&
+       &  "MED_TETRA4     ",&
+       &  "MED_PYRA5      ",&
+       &  "MED_PENTA6     ",&
+       &  "MED_HEXA8      ",&
+       &  "MED_TETRA10    ",&
+       &  "MED_PYRA13     ",&
+       &  "MED_PENTA15    ",&
+       &  "MED_HEXA20     ",&
+       &  "MED_POLYGON    ",&
+       &  "MED_POLYHEDRON "  /)
 
-  character(LEN=12),target,dimension(MED_NBR_GEOMETRIE_FACE+1) :: FMED_GEOMETRIE_FACE_AFF = (/&
-       &  "MED_TRIA3   ",&
-       &  "MED_TRIA6   ",&
-       &  "MED_QUAD4   ",&
-       &  "MED_QUAD8   ",&
-       &  "MED_POLYGONE" /)
+  character(LEN=15),target,dimension(5) :: FMED_GEOMETRIE_FACE_AFF = (/&
+       &  "MED_TRIA3      ",&
+       &  "MED_TRIA6      ",&
+       &  "MED_QUAD4      ",&
+       &  "MED_QUAD8      ",&
+       &  "MED_POLYGON    " /)
 
-  character(LEN=12),target,dimension(MED_NBR_GEOMETRIE_ARETE) :: FMED_GEOMETRIE_ARETE_AFF = (/&
-       &  "MED_SEG2    ",&
-       &  "MED_SEG3    " /)   
+  character(LEN=15),target,dimension(2) :: FMED_GEOMETRIE_ARETE_AFF = (/&
+       &  "MED_SEG2       ",&
+       &  "MED_SEG3       " /)   
 
-  character(LEN=12),target,dimension(1) :: FMED_GEOMETRIE_NOEUD_AFF = (/ &
-       &  "(AUCUN)     "/)  
+  character(LEN=15),target,dimension(1) :: FMED_GEOMETRIE_NOEUD_AFF = (/ &
+       &  "(AUCUN)        "/)  
 
 
-  character(LEN=17),target,dimension(0:4) :: FMED_ENTITE_MAILLAGE_AFF =(/ &
-       &  "MED_MAILLE       ", &
-       &  "MED_FACE         ", &
-       &  "MED_ARETE        ", &
-       &  "MED_NOEUD        ", &
-       &  "MED_NOEUD_MAILLE "/)
+  character(LEN=20),target,dimension(0:4) :: FMED_ENTITE_MAILLAGE_AFF =(/ &
+       &  "MED_CELL            ", &
+       &  "MED_DESCENDING_FACE ", &
+       &  "MED_DESCENDING_EDGE ", &
+       &  "MED_NODE            ", &
+       &  "MED_NODE_ELEMENT    "/)
 
-  parameter (USER_MODE = MED_COMPACT )
+  parameter (USER_MODE = MED_COMPACT_PFLMODE )
 
   !!  write (*,'(A0)')  FMED_GEOMETRIE_NOEUD_AFF(1)
   !!  write (*,'(A0)')  FMED_GEOMETRIE_MAILLE_AFF(1)
   !!  write (*,'(A0)')  FMED_GEOMETRIE_FACE_AFF(1)
   !!  write (*,'(A0)')  FMED_GEOMETRIE_ARETE_AFF(1)
 
-  nbpdtnor=0;pflsize=0;ngauss=0;nval=0
+  locname=''
+  nbpdtnor=0;pflsize=0;ngauss=0;nent=0
   numdt = 0;numo=0;retmem=0
   cret=0;ret=0
 
@@ -348,178 +370,96 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage)
 
 
   select case (entite)
-  case (MED_NOEUD)
+  case (MED_NODE)
      type_geo => typ_noeud
      nb_geo   = 1
      AFF      => FMED_GEOMETRIE_NOEUD_AFF
-  case (MED_MAILLE)  
+  case (MED_CELL)  
      type_geo => typmai
-     nb_geo   = MED_NBR_GEOMETRIE_MAILLE+2
+     nb_geo   = 17
      AFF      => FMED_GEOMETRIE_MAILLE_AFF
-  case (MED_NOEUD_MAILLE)  
+  case (MED_NODE_ELEMENT)  
      type_geo => typmai
-     nb_geo   = MED_NBR_GEOMETRIE_MAILLE+2
+     nb_geo   = 17
      AFF      => FMED_GEOMETRIE_MAILLE_AFF
-  case (MED_FACE) 
+  case (MED_DESCENDING_FACE) 
      type_geo => typfac;
-     nb_geo   = MED_NBR_GEOMETRIE_FACE+1
+     nb_geo   = 5
      AFF      =>  FMED_GEOMETRIE_FACE_AFF
-  case  (MED_ARETE)
+  case  (MED_DESCENDING_EDGE)
      type_geo => typare
-     nb_geo   = MED_NBR_GEOMETRIE_ARETE
+     nb_geo   = MY_NOF_DESCENDING_EDGE_TYPE
      AFF      =>  FMED_GEOMETRIE_ARETE_AFF
   end select
 
   do k=1,nb_geo
 
      ! ** Combien de (PDT,NOR) a lire **
-     call efnpdt(fid,nomcha,entite,type_geo(k),nbpdtnor,ret) 
-     if (ret.ne.0) then
-        print *, "Impossible de lire le nombre de pas de temps : " &
-             & ,k,nomcha,entite,FMED_ENTITE_MAILLAGE_AFF(entite) &
-             & ,type_geo(k),AFF(type_geo(k))
-        cret = -1
-     end if
+     nbpdtnor = ncst
      if(nbpdtnor < 1 ) continue
 
-     do j=1,nbpdtnor
+     do j=1,ncst
 
-
-        call efpdti(fid, nomcha, entite, type_geo(k), &
-             & j, ngauss, numdt, numo, dt_unit,  &
-             & dt, maa_ass, local, nbrefmaa, ret ) 
+        call mfdcsi(fid,nomcha,j,numdt,numo,dt,ret) 
+        !print *,ret
         if (ret.ne.0) then
            print *, "Erreur a la demande d'information sur (pdt,nor) : " &
-                & ,nomcha,entite, type_geo(k), ngauss, numdt, numo, dt_unit &
-                & ,dt, maa_ass, local, nbrefmaa
+                & ,nomcha,entite, numdt, numo, dt
            cret = -1
         end if
 
-        if (numdt .eq. MED_NOPDT) then
-           write(*,'(5X,A)') 'Pas de pas de temps'
-        else
-           write(*,'(5X,A,I5,A,E20.8,A,A,A)') 'Pas de temps n ' &
-                &  ,numdt,' (', dt ,') ', 'et d''unite ',TRIM(dt_unit)
-        endif
-        if (numo .eq. MED_NONOR) then
-           write(*,'(5X,A)')     'Pas de numero d''ordre'
-        else
-           write(*,'(5X,A,I5)')  'Numero d ordre            : ', numo
-        endif
-        write(*,'(5X,A,I5)') 'Nombre de points de gauss : ',ngauss
-        write(*,'(5X,A,A)')  'Maillage associe          : ', TRIM(maa_ass)
-
-        ! ** Le maillage reference est-il porte par un autre fichier **
-        if ( .not. local ) then
-           call efnvli(fid,maa_ass,nvl,ret)
-           if (ret.ne.0) then
-              print *, "Erreur a la lecture de la taille du lien : " &
-                   & , maa_ass, local, nvl
-              cret = -1
-           end if
-           !! allocate(lien(nvl),STAT=retmem)
-           if (retmem .ne. 0) then
-              print *, "Erreur a l'allocation mmoire de lien : "
-              call efexit(-1)
-           endif
-           lien =""
-           call efliel(fid,lien,nvl,maa_ass,ret)
-           if (ret.ne.0) then
-              print *,"Erreur a la lecture du lien : " & 
-                   & ,maa_ass,lien
-              cret = -1
-           else 
-              write (*,'(5X,A,A,A,A,A)') 'Le maillage |',TRIM(maa_ass), &
-                   & '| est porte par un fichier distant |', &
-                   & TRIM(lien),'|'
-           endif
-           !! deallocate(lien)
-        endif
-
-        ! ** Combien de maillages lies aux (nomcha,ent,geo,numdt,numo)  **
-        ! ** Notons que cette information est egalement disponible ** 
-        ! ** a partir de MEDpasdetempsInfo **
-        call efnref(fid,nomcha,entite,type_geo(k),numdt,numo,nref,ret)
+        call mfdnpf(fid,nomcha,numdt,numo,entite,type_geo(k),pflname,locname,nprofile,ret)
+        !print *,ret
         if (ret.ne.0) then
-           print *,"Erreur a la demande du nombre de maillages references par le champ : ", & 
-                & nomcha,numdt,numo
-           cret = -1; continue
-        endif
+           print *, "Erreur a la lecture du nombre de profil : " &
+                & ,nomcha,entite, type_geo(k),numdt, numo
+           cret = -1
+           call efexit(cret)
+        end if
 
-        do l=1,nbrefmaa
-
-           call efrefi(fid,nomcha,entite,type_geo(k), &
-                & l,numdt, numo, maa_ass, local, ngauss, ret)
-           if (ret.ne.0) then
-              print *,"Erreur a la demande d'information sur le maillage utilise par le champ n : " & 
-                   & ,nomcha,entite,type_geo(k), &
-                   & l,numdt, numo, maa_ass
-              cret = -1; continue
-           endif
-
-           ! ** Prend en compte le nbre de pt de gauss automatiquement **
-           call efnval(fid,nomcha,entite,type_geo(k),numdt,numo,maa_ass,USER_MODE,nval,cret)
+        do l=1,nprofile
+           
+           ! ** Combien de valeurs à lire ? **
+           call mfdnvp(fid,nomcha,numdt,numo,entite,type_geo(k),l,USER_MODE,pflname,pflsize,locname,ngauss,nent,ret)
+           !print *,ret
            if (ret.ne.0) then
               print *,"Erreur a la lecture du nombre de valeurs du champ : " & 
                    & ,nomcha,entite,type_geo(k), &
-                   & numdt, numo, maa_ass
+                   & numdt, numo
               cret = -1; continue
            endif
-           write(*,'(5X,A,I5,A,I5,A,A,A,A,A,A,A,I5,A)') &
-                & 'Il y a ',nval,' valeurs en mode ',USER_MODE, &
-                & ' . Chaque entite ',TRIM(FMED_ENTITE_MAILLAGE_AFF(entite)), &
-                & ' de type geometrique ',TRIM(AFF(k)),' associes au maillage |',&
-                & TRIM(maa_ass),'| a ',ngauss,' pts de gauss '
-
-           ! ** Le maillage reference est-il porte par un autre fichier **
-           if ( .not. local ) then
-
-              call efnvli(fid,maa_ass,nvl,ret)
-              if (ret.ne.0) then
-                 print *, "Erreur a la lecture de la taille du lien : " &
-                      & , maa_ass, local, nvl
-                 cret = -1
-              end if
-
-              !! allocate(lien(nvl),STAT=retmem)
-              if (retmem .ne. 0) then
-                 print *, "Erreur a l'allocation mmoire de comp et unit : "
-                 call efexit(-1)
-              endif
-
-              call efliel(fid,lien,nvl,maa_ass,ret)
-              if (ret.ne.0) then
-                 print *,"Erreur a la lecture du lien : " & 
-                      & ,maa_ass,lien
-                 cret = -1
-              else 
-                 write(*,'(5X,A,A,A,A,A)') 'Le maillage |',TRIM(maa_ass), &
-                      & '| est porte par un fichier distant |',TRIM(lien),'|'
-              endif
-              !! deallocate(lien)
-           endif
+           !write(*,'(5X,A,I5,A)')  'Il y a ', nent ,' valeurs a lire '
+           
+           write(*,'(5X,A,I2,A,I2,A,I2,A,E10.5,A)')  'Séquence de calcul n° ',l,' (',numdt,',',numo,'), dt=(',dt,')'
+           write(*,'(5X,A,I5,A,I2,A,A,A,A,A,A,I2,A,A)') &
+                & 'Il y a ',nent,' valeurs en mode ',USER_MODE, &
+                & '. Chaque entite ',TRIM(FMED_ENTITE_MAILLAGE_AFF(entite)), &
+                & ' de type geometrique ',TRIM(AFF(k)),' associes au profil |',&
+                & TRIM(pflname)//'| a ',ngauss,' valeur(s) par entité une localization de nom |',TRIM(locname)//'|'
 
            ! **Lecture des valeurs du champ **
            if (typcha .eq. MED_FLOAT64) then
-              allocate(valr(ncomp*nval),STAT=retmem)
-
-              call efchal(fid,maa_ass,nomcha,valr,stockage,MED_ALL,locname, &
-                   & pflname,USER_MODE,entite,type_geo(k),numdt,numo,ret)
-
+              allocate(valr(ncomp*nent*ngauss),STAT=retmem)
+              
+              call mfdrpr(fid,nomcha,numdt,numo,entite,type_geo(k),USER_MODE, &
+                   &      pflname,stockage,MED_ALL_CONSTITUENT,valr,ret)
+              !print *,ret
               if (ret.ne.0) then
-                 print *,"Erreur a la lecture du nombre de valeurs du champ : ", &
-                      &  maa_ass,nomcha,valr,stockage,MED_ALL,locname, &
+                 print *,"Erreur a la lecture des valeurs du champ : ", &
+                      &  nomcha,valr,stockage,MED_ALL_CONSTITUENT, &
                       &  pflname,USER_MODE,entite,type_geo(k),numdt,numo
                  cret = -1;
+                 call efexit(cret)
               endif
            else	  
-              allocate(vale(ncomp*nval),STAT=retmem)
+              allocate(vale(ncomp*nent*ngauss),STAT=retmem)
 
-              call efchal(fid,maa_ass,nomcha,vale,stockage,MED_ALL,locname, &
-                   &  pflname,USER_MODE,entite,type_geo(k),numdt,numo,ret)
+              call mfdipr(fid,nomcha,numdt,numo,entite,type_geo(k),USER_MODE, &
+                   &      pflname,stockage,MED_ALL_CONSTITUENT,vale,ret)
+              !print *,ret
               if (ret.ne.0) then
                  print *,"Erreur a la lecture des valeurs du champ : ",&
-                      & maa_ass,nomcha,vale,stockage,MED_ALL,locname, &
+                      & nomcha,vale,stockage,MED_ALL_CONSTITUENT, &
                       & pflname,USER_MODE,entite,type_geo(k),numdt,numo
                  cret = -1;
               endif
@@ -527,11 +467,11 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage)
            endif
 
            if (ngauss .gt. 1 ) then
-              write (*,'(5X,A,A,A)') "- Modle de localisation des ", &
+              write (*,'(5X,A,A,A)') "- Modèle de localisation des ", &
                    & "points de Gauss de nom ", TRIM(locname)
            end if
 
-           if ( entite .eq. MED_NOEUD_MAILLE ) then
+           if ( entite .eq. MED_NODE_ELEMENT ) then
               ngroup = MOD(type_geo(k),100)
            else
               ngroup = ngauss
@@ -540,7 +480,7 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage)
            select case (stockage) 
            case (MED_FULL_INTERLACE)  
               write(*,'(5X,A)') "- Valeurs :";  write(*,'(5X,A)') ""
-              do m=0,(nval/ngroup-1)
+              do m=0,nent-1
                  write(*,*) "|"
                  do n=0,(ngroup*ncomp-1)
                     if (typcha .eq. MED_FLOAT64) then
@@ -554,11 +494,11 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage)
               write(*,'(5X,A)') "- Valeurs :";  write(*,'(5X,A)') ""
               do m=0,ncomp-1
                  write(*,*) "|"
-                 do n=0,nval-1 
+                 do n=0,nent-1 
                     if (typcha .eq. MED_FLOAT64) then
-                       write (*,'(1X,E20.5,1X)') valr(m*nval+n +1)
+                       write (*,'(1X,E20.5,1X)') valr(m*nent+n +1)
                     else
-                       write (*,'(1X,I8,1X)') vale(m*nval+n +1)
+                       write (*,'(1X,I8,1X)') vale(m*nent+n +1)
                     endif
                  enddo
               enddo
@@ -572,11 +512,11 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage)
            endif
 
            !* Profils
-           if (pflname .eq. MED_NOPFL) then
-              write(*,'(5X,A)') 'Pas de profil'
+           if (pflname .eq. MED_NO_PROFILE) then
+              !write(*,'(5X,A)') 'Pas de profil'
            else
               write(*,'(5X,A,A)') 'Profil :',pflname
-              call efnpfl(fid,pflname,pflsize,ret)
+              call mpfpsn(fid,pflname,pflsize,ret)
               if (ret .ne. 0) then
                  print *,"Erreur a la lecture du nombre de valeurs du profil : ", &
                       & pflname,pflsize
@@ -587,11 +527,11 @@ integer function getFieldsOn(fid, nomcha, typcha, ncomp, entite, stockage)
               ! ** allocation memoire de pflval **
               allocate(pflval(pflsize),STAT=retmem)
               if (retmem .ne. 0) then
-                 print *, "Erreur a l'allocation mmoire de pflsize : "
+                 print *, "Erreur a l'allocation mémoire de pflsize : "
                  call efexit(-1)
               endif
 
-              call efpfll(fid,pflval,pflname,ret)
+              call mpfprr(fid,pflname,pflval,ret)
               if (cret .ne. 0) write(*,'(I1)') cret
               if (ret .ne. 0) then
                  print *,"Erreur a la lecture du profil : ", &
