@@ -33,4 +33,9 @@ extern void MAJ_21_22_maillages            (med_idt fid);
 extern void MAJ_21_22_noeuds_maillage      (med_idt mid, med_int dimension);
 extern void MAJ_21_22_profils              (med_idt fid,med_int nprofil);
 
+/* depuis la 3.0.0*/
+med_err _MED23v30stringConvert(char *chaine30, med_int substrsize30,
+			       char *chaine23, med_int substrsize23,
+			       med_int nsubstr );
+
 #endif
