@@ -33,10 +33,10 @@ int main(int argc, char *argv[]) {
   try {
     ret = MEDimport(argv[1], fileOut) ;
   } catch ( std::exception &ex) {
-    std::cout << "Une erreur est survenue  l'xcution de medImport" << std::endl;
+    std::cout << "Une erreur est survenue à l'éxécution de medImport" << std::endl;
     std::cout << ex.what() << std::endl;
   }
   return ret;
-  
+
 }
 
